@@ -5,7 +5,7 @@ import traceback
 import re
 import time
 from xml.sax import saxutils
-
+import sqlite3
 import setproctitle
 import click
 import configparser
@@ -22,18 +22,17 @@ from prompt_toolkit.history import FileHistory
 from prompt_toolkit.shortcuts import PromptSession
 from prompt_toolkit.formatted_text import HTML
 
-from .cmdexecute import CmdExecute
-from .cmdmapping import CmdMapping
-from .hdfswrapper import HDFSWrapper
-from .testcliexception import TestCliException
-from .testclimeta import TestCliMeta
-from .testclijobmanager import JOBManager
-from .testclitransactionmanager import TransactionManager
-from .datawrapper import DataWrapper
-from .testoption import TestOptions
-from .__init__ import __version__
-from .sqlparse import SQLAnalyze
-from .apiparse import APIAnalyze
+from testcli.cmdexecute import CmdExecute
+from testcli.cmdmapping import CmdMapping
+from testcli.hdfswrapper import HDFSWrapper
+from testcli.testcliexception import TestCliException
+from testcli.testclijobmanager import TestCliMeta
+from testcli.testclijobmanager import JOBManager
+from testcli.datawrapper import DataWrapper
+from testcli.testoption import TestOptions
+from testcli.__init__ import __version__
+from testcli.sqlparse import SQLAnalyze
+from testcli.apiparse import APIAnalyze
 
 OFLAG_LOGFILE = 1
 OFLAG_LOGGER = 2
@@ -70,7 +69,7 @@ class TestCli(object):
             nologo=False,                           # 是否不打印登陆时的Logo信息，True的时候不打印
             breakWithError=False,                   # 遇到命令行错误，是否中断脚本后续执行，立刻退出
             breakErrorCode=255,                     # 遇到命令行错误时候的退出代码
-            sqlperf=None,                           # SQL审计文件输出名，None表示不需要
+            xlog=None,                              # 扩展日志信息文件输出名，None表示不需要
             Console=sys.stdout,                     # 控制台输出，默认为sys.stdout,即标准输出
             HeadlessMode=False,                     # 是否为无终端模式，无终端模式下，任何屏幕信息都不会被输出
             WorkerName='MAIN',                      # 程序别名，可用来区分不同的应用程序,
@@ -90,7 +89,6 @@ class TestCli(object):
         self.testOptions = TestOptions()                # 程序运行中各种参数
         self.HdfsHandler = HDFSWrapper()                # HDFS文件操作
         self.JobHandler = JOBManager()                  # 并发任务管理器
-        self.TransactionHandler = TransactionManager()  # 事务管理器
         self.DataHandler = DataWrapper()                # 随机临时数处理
         self.MetaHandler = TestCliMeta()                # SQLCli元数据
         self.SpoolFileHandler = []                      # Spool文件句柄, 是一个数组，可能发生嵌套
@@ -100,10 +98,9 @@ class TestCli(object):
         self.prompt_app = None                          # PromptKit控制台
         self.echofilename = None                        # 当前回显文件的文件名称
         self.Version = __version__                      # 当前程序版本
-        self.SQLPerfFile = None                         # SQLPerf文件名
-        self.SQLPerfFileHandle = None                   # SQLPerf文件句柄
-        self.PerfFileLocker = None                      # 进程锁, 用来在输出perf文件的时候控制并发写文件
-        self.xlogfilename = None                        # xlog文件名
+        self.xlogFile = None                            # xlog文件名
+        self.xlogFileHandle = None                      # xlog文件句柄
+        self.xlogFileLocker = None                      # 进程锁, 用来在输出perf文件的时候控制并发写文件
         self.breakWithError = breakWithError            # 是否在遇到错误的时候退出
         self.breakErrorCode = breakErrorCode            # 遇到错误的退出代码
         
@@ -141,7 +138,7 @@ class TestCli(object):
         self.logfilename = logfilename
         self.Console = Console
         self.HeadlessMode = HeadlessMode
-        self.SQLPerfFile = sqlperf
+        self.xlogFile = xlog
         if HeadlessMode:
             self.Console = open(os.devnull, "w")
         self.logger = logger
@@ -190,10 +187,9 @@ class TestCli(object):
         self.JobHandler.setProcessContextInfo("logon", self.logon)
         self.JobHandler.setProcessContextInfo("nologo", self.nologo)
         self.JobHandler.setProcessContextInfo("commandMap", self.commandMap)
-        self.JobHandler.setProcessContextInfo("sqlperf", sqlperf)
+        self.JobHandler.setProcessContextInfo("xlog", xlog)
         self.JobHandler.setProcessContextInfo("logfilename", self.logfilename)
         self.JobHandler.setProcessContextInfo("script", self.commandScript)
-        self.TransactionHandler.cmdExecuteHandler = self.cmdExecuteHandler
 
         # 设置其他的变量
         self.cmdExecuteHandler.cliHandler = self
@@ -299,7 +295,6 @@ class TestCli(object):
             # 对于被主进程调用的进程，则不需要考虑, 连接到主进程的Meta服务商
             self.MetaHandler.ConnectServer(m_JobManagerURL)
             self.JobHandler.setMetaConn(self.MetaHandler.dbConn)
-            self.TransactionHandler.setMetaConn(self.MetaHandler.dbConn)
             self.testOptions.set("JOBMANAGER_METAURL", m_JobManagerURL)
 
         # 处理传递的映射文件, 首先加载参数的部分，如果环境变量里头有设置，则环境变量部分会叠加参数部分
@@ -344,6 +339,10 @@ class TestCli(object):
             self.MetaHandler.ShutdownServer()
             self.MetaHandler = None
 
+        # 关闭xlog的文件句柄
+        if self.xlogFileHandle is not None:
+            self.xlogFileHandle.close()
+
     # 执行特殊的命令
     @staticmethod
     def execute_internal_command(cls, arg, **_):
@@ -574,7 +573,7 @@ class TestCli(object):
                         else:
                             self.echo(p_result["message"])
                     elif p_result["type"] == "statistics":
-                        self.Log_Statistics(p_result)
+                        self.writeExtendLog(p_result)
                     else:
                         raise TestCliException("internal error. unknown sql type error. " + str(p_result["type"]))
                 else:
@@ -728,17 +727,19 @@ class TestCli(object):
                 currentPwd = os.getcwd()
                 scriptDir = os.path.dirname(str(self.commandScript))
                 scriptBase = os.path.basename(str(self.commandScript))
-                os.chdir(scriptDir)
+                if scriptDir.strip() != "":
+                    # 如果脚本不是当前目录，需要切换到脚本目录下
+                    # 如果脚本是当前目录，切换到空目录会报错，所以不能切换
+                    os.chdir(scriptDir)
                 self.DoCommand('_start ' + scriptBase)
-                os.chdir(currentPwd)
+                if scriptDir.strip() != "":
+                    # 如果发生了脚本切换，则执行脚本后要返回切换前的目录
+                    os.chdir(currentPwd)
             except TestCliException:
                 raise EOFError
             self.DoCommand('_exit')
         except (TestCliException, EOFError):
-            if self.testOptions.get("JOBMANAGER") == "ON":
-                # 如果还有活动的事务，标记事务为失败信息
-                for m_Transaction in self.TransactionHandler.getAllTransactions():
-                    self.TransactionHandler.TransactionFail(m_Transaction.Transaction_Name)
+            pass
 
         # 退出进程, 如果要求不显示logo，则也不会显示Disconnected字样
         if self.exitValue == 0:
@@ -1108,7 +1109,7 @@ class TestCli(object):
 
         return output
 
-    def Log_Statistics(self, p_SQLResult):
+    def writeExtendLog(self, commandResult):
         # 开始时间         StartedTime
         # 消耗时间         elapsed
         # SQL的前20个字母  SQLPrefix
@@ -1117,53 +1118,76 @@ class TestCli(object):
         # 线程名称         thread_name
 
         # 如果没有打开性能日志记录文件，直接跳过
-        if self.SQLPerfFile is None:
+        if self.xlogFile is None:
             return
 
         # 初始化文件加锁机制
-        if self.PerfFileLocker is None:
-            self.PerfFileLocker = Lock()
+        if self.xlogFileLocker is None:
+            self.xlogFileLocker = Lock()
 
         # 多进程，多线程写入，考虑锁冲突
         try:
-            self.PerfFileLocker.acquire()
-            if not os.path.exists(self.SQLPerfFile):
-                # 如果文件不存在，创建文件，并写入文件头信息
-                self.SQLPerfFileHandle = open(self.SQLPerfFile, "a", encoding="utf-8")
-                self.SQLPerfFileHandle.write("Script\tStarted\telapsed\tRawCommand\tCommand\t"
-                                             "CommandStatus\tErrorMessage\tWorkerName\t"
-                                             "Suite\tCase\tScenario\tTransaction\n")
-                self.SQLPerfFileHandle.close()
+            self.xlogFileLocker.acquire()
+            if self.xlogFileHandle is None:
+                # 如果文件已经存在，则删除当前文件
+                if os.path.exists(self.xlogFile):
+                    os.remove(self.xlogFile)
+                # 创建文件，并写入文件头信息
+                self.xlogFileHandle = sqlite3.connect(self.xlogFile)
+                cursor = self.xlogFileHandle.cursor()
+                cursor.execute("Create Table TestCli_Xlog "
+                               "("
+                               "  Script          TEXT,"
+                               "  Started         DATETIME,"
+                               "  Elapsed         NUMERIC,"
+                               "  RawCommand      TEXT,"
+                               "  Command         TEXT,"
+                               "  CommandStatus   INTEGER,"
+                               "  ErrorMessage    TEXT,"
+                               "  WorkerName      TEXT,"
+                               "  SuiteName       TEXT,"
+                               "  CaseName        TEXT,"
+                               "  Scenario        TEXT"
+                               ")"
+                               "")
+                cursor.close()
 
             # 对于多线程运行，这里的thread_name格式为JOB_NAME#副本数-完成次数
             # 对于单线程运行，这里的thread_name格式为固定的MAIN
-            m_ThreadName = str(p_SQLResult["thread_name"])
+            threadName = str(commandResult["thread_name"])
 
-            # 打开Perf文件
-            self.SQLPerfFileHandle = open(self.SQLPerfFile, "a", encoding="utf-8")
             # 写入内容信息
             if self.commandScript is None:
-                m_SQL_Script = "Console"
+                script = "Console"
             else:
-                m_SQL_Script = str(os.path.basename(self.commandScript))
-            self.SQLPerfFileHandle.write(
-                m_SQL_Script + "\t" +
-                time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(p_SQLResult["startedTime"])) + "\t" +
-                "%8.2f" % p_SQLResult["elapsed"] + "\t" +
-                str(p_SQLResult["rawCommand"]).replace("\n", " ").replace("\t", "    ") + "\t" +
-                str(p_SQLResult["command"]).replace("\n", " ").replace("\t", "    ") + "\t" +
-                str(p_SQLResult["commandStatus"]) + "\t" +
-                str(p_SQLResult["errorMessage"]).replace("\n", " ").replace("\t", "    ") + "\t" +
-                str(m_ThreadName) + "\t" +
-                str(self.suitename) + "\t" +
-                str(self.casename) + "\t" +
-                str(p_SQLResult["scenario"]) + "\t" +
-                str(p_SQLResult["transaction"]) +
-                "\n"
+                script = str(os.path.basename(self.commandScript))
+
+            # 打开xLog文件
+            if self.xlogFileHandle is not None:
+                self.xlogFileHandle = sqlite3.connect(self.xlogFile)
+            cursor = self.xlogFileHandle.cursor()
+            data = (
+                script,
+                time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(commandResult["startedTime"])),
+                "%8.2f" % commandResult["elapsed"],
+                str(commandResult["rawCommand"]),
+                str(commandResult["command"]),
+                str(commandResult["commandStatus"]),
+                str(commandResult["errorMessage"]),
+                str(threadName),
+                str(self.suitename),
+                str(self.casename),
+                str(commandResult["scenario"])
             )
-            self.SQLPerfFileHandle.flush()
-            self.SQLPerfFileHandle.close()
+            cursor.execute(
+                "Insert Into TestCli_Xlog(Script,Started,Elapsed,RawCommand,"
+                "Command,CommandStatus,ErrorMessage,WorkerName,SuiteName,CaseName,Scenario) "
+                "Values(?,?,?,?, ?,?,?,?,?,?,?)",
+                data
+            )
+            cursor.close()
+            self.xlogFileHandle.commit()
         except Exception as ex:
-            print("Internal error:: perf file write not complete. " + repr(ex))
+            print("Internal error:: xlog file [" + str(self.xlogFile) + "] write not complete. " + repr(ex))
         finally:
-            self.PerfFileLocker.release()
+            self.xlogFileLocker.release()
